OverhangStrategy

Enum OverhangStrategy 

#[repr(i8)]
pub enum OverhangStrategy { SoftClip = 9, InDel = 10, LeadingInDel = 11, Ignore = 12, }
How overhangs should be treated during Smith-Waterman alignment.

Variants



SoftClip = 9

Add softclips for the overhangs.



InDel = 10

Treat the overhangs as proper insertions/deletions.



LeadingInDel = 11

Treat the overhangs as proper insertions/deletions for leading (but not trailing) overhangs.

This is useful e.g. when we want to merge dangling tails in an assembly graph: because we don’t expect the dangling tail to reach the end of the reference path we are okay ignoring trailing deletions - but leading indels are still very much relevant.



Ignore = 12

Just ignore the overhangs.